****************************************************
*****PALESTINE: Fiscal Incidence Analysis***********
*************World Bank, Poverty and Equity GP*********
***********TTL: Arden Finn********
**************Prepared by: Jessica Anderson***********
**************Updated by: Beenish Amjad and Haydeeliz Carrasco***********
*******************************************************
*Date: April 12, 2022



*===============================================================================
	* SECTION A: Prepare property tax administrative data
*===============================================================================

* A.1 - Clean crosswalk to match CITY_ID (used in property tax administrative data) to id02 (used in PECS)
	import excel "${datapath}20220128_Municipal_Codes.xls", firstrow clear
	drop if id02 == .
	keep id02 CITY_ID CITY_NAME CITY_NAME_EN Governorate
	save "${temppath}municipal_codes", replace	

* A.2 - Import 2017 property tax administrative data

	// Number of property tax payers in 2017
	import excel "${datapath}Number of Property Tax payers 2017.xls", firstrow clear
	ren CityNumber CITY_ID
	compress, nocoalesce
	save "${temppath}total_proptaxpayers_2017", replace
	
	// Total property tax collections in 2017
	import excel "${datapath}Property tax collections 2017.xls", firstrow clear	
	codebook CITY_ID 
	drop if CITY_ID == "" // drop cities that cannot be matched to PECS	
	compress, nocoalesce
	save "${temppath}total_proptax_collections_2017", replace
	
	// 2017 property valuation data
	import excel "${datapath}Property Evaluations 2017.xls", firstrow clear
	format EvaluationAmount %12.0gc
	ren CityNo CITY_ID
	compress, nocoalesce
	save "${temppath}Property Evaluations 2017", replace

* A.3 - Merge crosswalk codes with 2017 property tax administrative data
	use "${temppath}municipal_codes", clear
	merge 1:1 CITY_ID using "${temppath}total_proptaxpayers_2017"				
	drop _m
	
	merge 1:1 CITY_ID using "${temppath}total_proptax_collections_2017"
	drop _m
	
	merge 1:1 CITY_ID using "${temppath}Property Evaluations 2017"
	drop _m
	
* A.4 - Identify core set of municipalities that collect property tax

	gen loc_proptax = 1
	replace loc_proptax = 0 if id02 == . // exclude 1 municipality without a PECS id (and no 2017 collections)
	replace loc_proptax = 0 if RECEIPT_AMT == . // exclude municipalities with no collections in 2017
	replace loc_proptax = 0 if NumberofTaxPayers == . // exclude municipalities with no taxpayers on record in 2017
	tab loc_proptax, m				//84 out 97 

* A.5 - Collapse property tax administrative data and indicator to level of PECS locality ids
	#d ;
	collapse 
		(sum) adm_taxpayers = NumberofTaxPayers adm_collections = RECEIPT_AMT
		(mean) mean_value = EvaluationAmount
		(max) loc_proptax 
	, by(id02) ;
	#d cr 
	
	compress, nocoalesce
	save "${temppath}adm_proptax", replace

* A.6 - Merge indicator for municipality property tax collection with PECS cover sheet data
	use "${datapath}PSE/cover", clear
	merge m:1 id02 using "${temppath}adm_proptax", keepusing(loc_proptax)
	drop if _m == 2
	drop _m	
	replace loc_proptax = 0 if loc_proptax == .
	lab var loc_proptax "HH located in a municipality that collects property tax"	
	compress, nocoalesce
	save "${temppath}property_tax_municipalities", replace

*===============================================================================
    * SECTION B: Create master dataset for property tax analysis
*===============================================================================
use "${datapath}\PSE\roster"
isid id00 d1

* B.1 - Merge in hh dwelling data
merge m:1 id00 using "${datapath}\PSE\dwelling"
drop _m

* B.2 - Merge PECS income section for information on land ownership	
merge m:1 id00 using "${datapath}\PSE\part6" 
drop _m

* B.3 - Merge in weights
merge 1:1 id00 d1 using "${datapath}\PSE\indvweight" 
drop _m

merge m:1 id00 using "${temppath}hhweight_quantiles" //HC: missing
drop _m

* B.4 - Merge indicator for municipalities that collect property tax
merge m:1 id00 using "${temppath}property_tax_municipalities" 
tab qc2 _m, m
drop if _m == 2 // none of the using-only observations represent complete interviews
drop _m

* B.5 - Merge in administrative data on property valuation
merge m:1 id02 using "${temppath}adm_proptax", keepusing(mean_value) 
tab _m loc_proptax, m
drop if _m == 2 // drop municipalities not in the PECS sample
drop _m
ren id00 hhid

* B.6 - Merge in household welfare variables
merge m:1 hhid using "${datapath}\PSE\PSE_2016_PECS_v01_M_v04_A_MNAPOV_3" 
drop _m
tab qc2, m
keep if qc2 == 1 // keep only completed interviews (drops municipalities out of PECS sample) 20185

* B.7 - Check characteristics of master dataset, label governorates, and save
	clonevar governorate = id01
	lab def lsef_governorate ///
		1 "jenin" 5 "tubas & northen valley" 10 "tulkarm" 15 "nablus" 20 "qalqilia" ///
		25 "salfit" 30 "ramallah & albireh" 35 "ariha & alaghwar" 40 "jerusalem j2" ///
		41 "jerusalem j1" 45 "bethlehem" 50 "hebron" 55 "north gaza" 60 "gaza" ///
		65 "deir al balah" 70 "khan yunis" 75 "rafah"
	lab val governorate lsef_governorate
	lab var governorate "Governorate"
	
	compress, nocoalesce
	save "${temppath}PSE_CEQ_PropertyTax_master", replace


*===============================================================================
	* SECTION C: Property tax parameters
*===============================================================================
use "${temppath}PSE_CEQ_PropertyTax_master", clear

* C.1 - Municipality property tax collection
	tab loc_proptax, m // about 33.75% of HHs live in municipalities that collect property tax
	tab loc_proptax region, m				

* Property tax is paid by "owners" on i)buildings ii)land annually at 17 percent of the annual rent value of buildings and real estate, after deducting 20 percent as consumption from the total cost of the lease
*C.2 - 1) Building ownership status 
	tab h3, m
	gen prop_owner = (h3 == 1)			//84.81% owner

*C.3 - Type of building (house, flat, villa or other)
	tab h1, m
	gen prop_villa = (h1 == 1)			//0.66%
	gen prop_house = (h1 == 2)			//56.12%
	gen prop_flat = (h1 == 3)			//43.12%
	gen prop_room = (h1 == 4)			//0.07%
	gen prop_other = (h1 == 5 | h1 == 6 |h1 == 7 |h1 == 10 )			

*C.4 - Lease cost 
	tab h5, m 		//majority purchased the house with personal "savings" and less than 5 % is paying to bank loan or to contractor
	gen mon_lease_payment = h7_1
	gen ann_lease_payment=(mon_lease_payment*12)
	
	*currency consideration
	clonevar ann_lease_NIS= ann_lease_payment if h7_2==1				
	replace ann_lease_NIS = ann_lease_payment* $JODtoNIS if h7_2==2 	
	replace ann_lease_NIS = ann_lease_payment* $USDtoNIS if h7_2==3 	
	
*C.5 - Estimated monthly rental value of dwellings (If you were to reside in a similar dwelling, what would be the estimated rental monthly value?)
	
	gen mon_rent = h10_1
	gen ann_rent= (mon_rent*12)
	tab ann_rent,m
	
	clonevar ann_rent_NIS=ann_rent if h10_2==1				
	replace ann_rent_NIS = ann_rent* $JODtoNIS if h10_2==2 	
	replace ann_rent_NIS = ann_rent* $USDtoNIS if h10_2==3 	
	
	*Using alternate question
	gen mon_rent_est = h9_1
	gen ann_rent_est= (mon_rent_est*12)
	
	clonevar ann_rent_NIS2=ann_rent_est if h9_2==1				
	replace ann_rent_NIS2 = ann_rent_est* $JODtoNIS if h9_2==2 	
	replace ann_rent_NIS2 = ann_rent_est* $USDtoNIS if h9_2==3 	

* C.6 - Land ownership
	tab i08, m		//1= yes = 35.17%
	gen land_owner=i08 if i08==1
	ren i09 area_land 			// BA: questionnaire "What is the area of the owned land by household[in M2]". In meter square
	bysort  governorate:  egen  avg_area_land = mean(area_land)

* C.7 - Average Land evaluation
	tab mean_value, m		//1= yes = 35.17%
	bysort  governorate:  egen  avg_land_evaluation = mean(mean_value)


*===============================================================================
	* SECTION D: Property tax estimation
*===============================================================================

* D.1 - Estimate property tax paid by household	on building (annual rental value * 20% deduction * 17% tax)
	*gen prop_tax_buil = ann_rent_NIS2 * 0.8 * 0.17 if prop_owner == 1 & loc_proptax == 1
	gen prop_tax_buil = ann_rent_NIS * 0.8 * 0.17 if loc_proptax == 1

	gen land_taxable=avg_area_land/avg_land_evaluation
	*gen prop_tax_land = land_taxable * 0.06 * 0.1 if land_owner == 1 & loc_proptax == 1
	gen prop_tax_land = land_taxable * 0.06 * 0.1 if loc_proptax == 1
	egen prop_tax_total = rowtotal(prop_tax_buil prop_tax_land), m
	sum prop_tax_total, d

*D2. Prepare some additional vars for analysis
	*Total nominal consumption
	gen gall_n_hh=gall_n*hhsize

*D3. Save dataset for analysis
collapse (first) region hhweight dec dec_wb_gz dec_wb dec_gz qui qui_wb_gz qui_wb qui_gz hhsize gall_n_hh prop_tax_total prop_tax_buil prop_tax_land, by(hhid)

save "${temppath}PSE_Prop tax results.dta", replace

*===============================================================================
	* SECTION E: Scaling down
*===============================================================================	
use "${temppath}PSE_Prop tax results.dta", clear 

* Sum up the Property tax in the survey 
	qui sum prop_tax_total [w=hhweight]
	loc propt_svy = (r(sum))
	disp `propt_svy'/1e6  //38.6

* Properyt tax in the admin data 
	loc propt_admn 14.3*1e6
	disp `propt_admn'
	disp $cons_admn
	disp (`propt_admn'/${cons_admn})
	disp 14.3/55087
	disp (`propt_svy'/$cons_svy)

* Calculate the scaling factor, using globals I set up earlier for consumption in the survey ($cons_svy) and consumption in the national accounts ($cons_adm)
	global prpt_scale = (`propt_admn'/$cons_admn)/(`propt_svy'/$cons_svy)
	disp $prpt_scale
	*/


* Scale down the Property tax by the calculated factor 
	gen prop_tax_adj=0
	replace prop_tax_adj = prop_tax_total*$prpt_scale
	
	gen buil_tax_adj=0
	replace buil_tax_adj = prop_tax_buil*$prpt_scale

	qui sum prop_tax_adj [w=hhweight]
	loc propt_svy = (r(sum))
	disp `propt_svy'/1e6

save "${temppath}PSE_Prop tax results.dta", replace

	
*===============================================================================
	* SECTION f: Preliminary analysis
*===============================================================================	
use   "${temppath}PSE_Prop tax results.dta", clear
collapse (sum) prop_tax_adj buil_tax_adj prop_tax_land  gall_n_hh [fw=int(hhweight)], by(region dec)
export excel using "$results\PSE_proptax results.xls", firstrow(var) sheet(Sheet1, modify) 

use   "${temppath}PSE_Prop tax results.dta", clear
collapse (sum) prop_tax_adj buil_tax_adj prop_tax_land  gall_n_hh [fw=int(hhweight)], by(region qui)
export excel using "$results\PSE_proptax results.xls", firstrow(var) sheet(Sheet2, modify) 

use   "${temppath}PSE_Prop tax results.dta", clear
collapse (sum) prop_tax_adj buil_tax_adj prop_tax_land  gall_n_hh [fw=int(hhweight)], by(region dec)
export excel using "$results\PSE_proptax results.xls", firstrow(var) sheet(Sheet1, modify) 




	
/*ASSUMPTIONS & LIMITATIONS:
1) Dwelling:
As per law, the property tax is paid only by owners, all property whether the property is rented, prepared for rent, or inhabited by the owners.
But the value of the tax varies depending on the occupancy status.
	a. If it is rented: according to the lease contract, if the contract is not clear, according to the rent value prevailing in the area.
	b. If it is prepared for rent: the owner pays the tax value that is higher than the owner and less than the lessor because he does not use it for the purpose of housing.
	c. If it’s inhabited by the owners: the tax is calculated based on the area of the land, the building area and the number of floors.

In our model: we are considering only owners as tax payers
	a. we are taking annual rental value to calculate the tax. For this we used h9 variable and not h10. There is huge variation in response of both questions and using h10 leads to zero property tax amount
	b. we don't have information about lease contract in the survey and details are not clease so we are using Annual rental value here as well
	c. we have i) number of floors ii) area of dwelling information in the survey so we will use annual rental value here as well

2) Land:
We calculated tax on the basis of valuation Amounts represented as the average value per square meter of property.
However the valuation amounts for some municipalities seems very high and varies a lot for several reasons (commercial area, industrial etc.). ARV effects the pricing as well.
Government has classified the municipalities into five categories (A, B, C, D, and E) based on above factors.
We were told that "valuation value is the average value prevailing in each municipality".
This is not clear. Average value irrespective of the area?
For now we have modelled with the assumption that it is Average value per square meter.
	
	
	
	
	
	
	
	
	
