*********************************************
*****PALESTINE: Fiscal Incidence Analysis*********
*****World Bank, Poverty and Equity GP*************
***********TTL: Arden Finn and Alia Jane************
*********Consultant: Haydeeliz Carrasco*************
****************************************************
*Date:  June 2nd, 2022
*Modified: Nov. 17th, 2022
/* Maya: note that this file is identical to the one that Haydeeliz uploaded on the 25 Jan, but I downloaded it later, and so the time-stamp looks as if it is later, 
	so I re-uploaded it so that all my files would have the same time-stamp, and I would know that they were updated appropriately. */


	/*
	Notes: 

Take estimates of consumption informality - ranging from 78% in decile 1 to 48% in decile 10. 
In the Bachas paper, total household consumption includes market and non-market transactions. 
So we calculate in the PECS the self-consumption share by decile, and then we deduct the self-consumption to get the rate for market goods only. 
After using informality we come up with too-low a number, and so we use a scaling factor to increase the size to match the amounts in the national accounts. 
	*/

clear 
set more off
set type double

/*------------------------------------/
         SET SIMULATION PARAMETERS
---------------------------------------*/
global vat_pa=0.16 //Standard VAT rate for Palestine
global vat_isr=0.17 //Standard VAT rate for Israel
global vat_scale=  1.5976   //Scaling factor to match the VAT effective rate of 6.6%


/*------------------------------------/
          A.    DATA PREPARATION
---------------------------------------*/

*A1. Prepare Excel with VAT rates**
import excel "${datapath}VAT rates_for STATA.xlsx", sheet("Main") cellrange(A1:I924) firstrow clear 
ren stata_code item
destring item, replace
drop if item==.
save "${temp}VAT rates_final.dta", replace 


*A2. Prepare Excel with COICOP -IO Mapping
import excel "${io}Augmented IO_West Bank_v3.xlsx", sheet("IO COICOP") cellrange(A1:B924) firstrow clear 
destring item, replace
drop if item==.
ta sector if item==2401
replace sector=10 if item==2104 | item==105 | item==1508 //imported cigarettes, imported wheat flour and imported chocolate mapped to Trade
save "${temp}IOmatrix_coicop.dta", replace

*A3. Import Master Dataset of HH consumption
use "${datapath}PSE\PSE_Master Consumption.dta", clear
sort item

*A4. Merge Master Dataset with Excel VAT rates
merge m:1 item using "${temp}VAT rates_final.dta" 
ta item if _m==1, nol //all=in-kind gifts (no problem since they are not part of VAT model)
drop if _m!=3
drop _m

rename id00 hhid
save "${temppath}PSE_Master VAT dataset.dta", replace

*A5. Merge with dataset that has welfare indicators
clear
*use "${datapath}PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta", clear ///dataset with welfare aggregates //WHY CANNOT OPEN THIS DATASET

use "${datapath}\PSE\PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta", clear
merge 1:m hhid using  "${temppath}PSE_Master VAT dataset.dta"
drop if _m!=3 //only keep HH's that are in the poverty dataset
drop _m

*A6. Merge with dataset that has hh weights
merge m:1 hhid using "${temppath}hhweight_v2.dta"
drop if _m!=3 //Drop observations without household weights
drop _m

*A7. Merge with COICOP-IO Matrix mapping 
sort item
merge m:1 item using "${temp}IOmatrix_coicop.dta" 
drop _m

*A8. Merge with estimations of IO indirect effects 
merge m:1 sector using "${temppath}PSE_VAT_IO indeff.dta"
drop if _m==2 //33 IO sectors not matched
drop _m


*A9. MERGE WITH CONSUMPTION INFORMALITY ESTIMATES BY DECILE (BACHAS et al. 2020)

*Total nominal consumption
gen gall_n_hh=gall_n*hhsize

*Generate deciles for total expenditure 
quantiles gall_n_hh [w=hhweight] if region ==1, nq(10) gencatvar(expend_dec1)
quantiles gall_n_hh [w=hhweight] if region ==2, nq(10) gencatvar(expend_dec2) 
gen decile_expend=expend_dec1 if region==1 
replace decile_expend=expend_dec2 if region==2
sort decile_expend 


merge m:1 decile_expend using "${io}avg informality for PSE_v2.dta"
drop if _m==2 //31 obs from master not matched
drop _m

*A10. MERGE WITH DWELLING DATASET (Identify HH owners and drop imputed rent)
ren hhid id00
merge m:1 id00 using "${datapath}\PSE\dwelling.dta" 
drop if _m==2
drop _m
gen hh_owner=1 if h3==1
ren id00 hhid

*A11. Prepare other relevant variables (regions, deciles)

*Location variables 
ta id01
ta region, nol

gen region_2=region 
	replace region_2=3 if id01==40|id01==41

label define region 1 "West Bank" 2 "Gaza" 3 "East Jerusalem"
label val region_2 region

*Deciles of real per capita consumption
gen popweight=hhweight*hhsize

**Option 1: Deciles of real per capita consumption differentiated by region
xtile dec1=gall [fw=int(popweight)] if region==1, n(10) //change command with quantiles 
xtile dec2=gall [fw=int(popweight)] if region==2, n(10) //change command with quantiles
gen decile=dec1 if region==1 
replace decile=dec2 if region==2

**Option 2: Deciles at the national level
xtile dec_nac=gall [fw=int(popweight)], n(10)

*A11. Save Master dataset for VAT analysis
save "${temppath}PSE_Master VAT dataset_v2.dta", replace


/*------------------------------------/
          B.    CALCULATION OF TAXES
---------------------------------------*/

*B1. Exclude expenditures that are outside the VAT base
drop if item>=2201 & item<=2233 //drop own consumption/self-production
drop if item==4507 | item==4508 | item==4513 //drop zakat and charities (4507); gifts in cash (4508) and in-kind gifts (4513)
drop if item>=5201 & item<=5206 | item>=5101 & item <=5140 | item==5302 | item== 5308 | item==5331 | item==5332 | item==5310 | item==5317 | item==5333 // DROP DURABLES
drop if item==29002 //HC: Based on Arden's feedback. Drop estimated rental value for all households (mostly imputed rent since over 80% of hhs are owners)

*B2. Netting down (Previosuly called grossing up expenditures), differentiated by location
gen gross_expend=mvalue/(1+vat_isr) if region_2==3 //East Jerusalem, deflated by Israeli VAT rates
	replace gross_expend=mvalue/(1+vat_pa) if region_2==1 //West Bank, deflated by Palestinian VAT rates
	replace gross_expend=mvalue if region_2==2 //Gaza, assume no VAT
	
*B3. Calulate direct effects from VAT, differentiated by location
*Note: Direct Effects only applied for share of formal budget 
gen vat_d=gross_expend*$vat_isr*(1-inf_mkt)*12 if region_2==3 & vat_isr!=0 //EJ
	replace vat_d=gross_expend*$vat_pa*(1-inf_mkt)*12 if region_2==1 & vat_pa!=0 //WB
	replace vat_d=0 if vat_d==. //Gaza

*B4. Calculate indirect effects from VAT (for exempt and informal goods=not eligible for VAT input credit)
replace indirectfix=-indirectfix

gen vat_ind=0
	replace vat_ind=(mvalue/(1+indirectfix))*indirectfix*(1-inf_mkt)*12 if region_2==1 & exempt_pa==1 //WB (Indirect effects for formal and exempt, calculated based on West Bank IO)
	replace vat_ind=(mvalue/(1+indirectfix))*indirectfix*(inf_mkt)*12 if region_2==1 & exempt_pa==. //Indirect effects for informal share in West Bank
	replace vat_ind=0 if item==2104 | item==105 | item==1508 //HC: Imported final goods should not have indirect effects from Domestic IO

*B5. Aggregate direct and indirect effects
gen TOT_VAT=vat_d+vat_ind	

*Downscale Total VAT to match VAT effective rate in the macro accounts (Total VAT collected from PA/Total Consumption in PA)=6.6%
	gen TOT_VAT_adj=$vat_scale*TOT_VAT
	gen vat_d_adj=$vat_scale*vat_d
	gen vat_ind_adj=$vat_scale*vat_ind

save "${temppath}PSE_Master VAT dataset_v3.dta", replace


*B6. Aggregate results at the HH level
use "${temppath}PSE_Master VAT dataset_v3.dta", clear
collapse (first) region region_2 decile hhweight popweight hhsize gall_n_hh (sum) TOT_VAT vat_d vat_ind TOT_VAT_adj vat_d_adj vat_ind_adj, by(hhid)

label var gall_n_hh "HH nominal consumption annual"
label var vat_d "VAT direct effects, annual, HH"
label var vat_ind "VAT indirect effects (WB), annual, HH"
label var TOT_VAT "Total VAT (direct and indirect eff), annual, HH"

label var vat_d_adj "VAT direct effects, annual, HH (upscaled)"
label var vat_ind_adj "VAT indirect effects (WB), annual, HH (upscaled)"
label var TOT_VAT_adj "Total VAT, annual, HH (upscaled)"

save "${temppath}PSE_VAT results_HH.dta", replace


/*------------------------------------/
          C. PRELIMINARY ANALYSIS
---------------------------------------*/
use  "${temppath}PSE_VAT results_HH.dta", clear
collapse (sum) TOT_VAT vat_d vat_ind gall_n_hh [fw=int(hhweight)], by(region_2 decile)
export excel using "$results\PSE_VAT results.xls", firstrow(var) sheet(Sheet1, modify) 

use  "${temppath}PSE_VAT results_HH.dta", clear
collapse (sum) TOT_VAT_adj vat_d_adj vat_ind_adj gall_n_hh [fw=int(hhweight)], by(region_2 decile)
export excel using "$results\PSE_VAT results.xls", firstrow(var) sheet(Sheet2, modify) 

use  "${temppath}PSE_VAT results_HH.dta", clear
collapse (sum) TOT_VAT_adj vat_d_adj vat_ind_adj gall_n_hh [fw=int(hhweight)], by(region decile)
export excel using "$results\PSE_VAT results.xls", firstrow(var) sheet(Sheet3, modify) 

*Check VAT results by COICOP
use "${temppath}PSE_Master VAT dataset_v3.dta", clear
collapse (sum) TOT_VAT vat_d vat_ind gall_n_hh [fw=int(hhweight)], by(item)
export excel using "$results\PSE_VAT results.xls", firstrow(var) sheet(Sheet5, modify) 
