*********************************************
*****PALESTINE: Fiscal Incidence Analysis*********
*****World Bank, Poverty and Equity GP*************
***********TTL: Arden Finn and Alia Jane************
*********Consultant: Haydeeliz Carrasco*************
****************************************************
*Date:  March 29th 2022

/*DOFILE: CALCULATION OF CUSTOM DUTIES*/

clear 
set more off
set type double


/* 
Had a vector of tax rates for Israel and for Palestine. 
Assume that people in EJ are paying the Israeli tax rates, and those in WB are paying the Palestine tax rates.
Don't use the scaling down parameter in the end because there was no overestimation.  

*/

/*------------------------------------/
         SET SIMULATION PARAMETERS
---------------------------------------*/
/*NOTE: Given the heterogeneity of rates and given that some items are based on average rates or different HS codes, it is not straightforward how to set standardized simulation parameters */
global duty_scale=1

/*------------------------------------/
          A.    DATA PREPARATION
---------------------------------------*/

*A1. Prepare Excel with Custom Duty rates**
import excel "${datapath}Custom duty rates_for STATA.xlsx", sheet("Main") cellrange(A1:J924) firstrow clear 
ren item_code item
destring item, replace
drop if item==.
save "${temp}Custom duty rates_final.dta", replace 


/**A2. Prepare Excel with COICOP -IO Mapping
import excel "${datapath}Augmented IO_West Bank_v2.xlsx", sheet("IO COICOP") cellrange(A1:B924) firstrow clear 
destring item, replace
drop if item==.
save "${datapath}IOmatrix_coicop.dta", replace */

*A3. Import Master Dataset of HH consumption
use "${datapath}/PSE/PSE_Master Consumption.dta", clear
sort item

*A4. Merge Master Dataset with Excel VAT rates
merge m:1 item using "${temp}Custom duty rates_final.dta" 
ta item if _m!=3, nol 
drop if _m!=3
drop _m

rename id00 hhid
save "${temppath}PSE_Master custom duty dataset.dta", replace

*A5. Merge with dataset that has welfare indicators
clear
*use "${datapath}PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta", clear ///dataset with welfare aggregates //WHY CANNOT OPEN THIS DATASET

use "${datapath}/PSE/PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta", clear
merge 1:m hhid using  "${temppath}PSE_Master custom duty dataset.dta"
drop if _m!=3 //only keep HH's that are in the poverty dataset
drop _m
codebook hhid //ok- 3739 hh's

*A6. Merge with dataset that has hh weights
merge m:1 hhid using "${temppath}hhweight_v2.dta"
drop if _m!=3 //Drop observations without household weights
drop _m

*A7. Merge with COICOP-IO Matrix mapping 
/*sort item
merge m:1 item using "${datapath}IOmatrix_coicop.dta" 
drop _m

*A8. Merge with estimations of IO indirect effects 
merge m:1 sector using "${temppath}PSE_VAT_IO indeff.dta"
drop if _m==2 //33 IO sectors not matched
drop _m*/

/*
*A9. Merge with file of informality
merge m:1 hhcode using "${temppath}Informality shares_hh.dta"
drop if _m==2
drop _m
*/

*A10. Prepare other relevant variables (regions, deciles)

*Location variables 
ta id01
ta region, nol

gen region_2=region 
	replace region_2=3 if id01==40|id01==41

label define region 1 "West Bank" 2 "Gaza" 3 "East Jerusalem"
label val region_2 region


**Option 1: Deciles of real per capita consumption differentiated by region
quantiles gall [w=popw] if region ==1, nq(10) gencatvar(dec1)
quantiles gall [w=popw] if region ==2, nq(10) gencatvar(dec2)
gen decile=dec1 if region==1 
replace decile=dec2 if region==2

**Option 2: Deciles at the national level
quantiles gall [w=popw], nq(10) gencatvar(dec_nac)

*Total nominal consumption
gen gall_n_hh=gall_n*hhsize

*A11. Save Master dataset for VAT analysis
save "${temppath}PSE_Master custom duty dataset_v2.dta", replace


/*------------------------------------/
          B.    CALCULATION OF TAXES
---------------------------------------*/

*B1. Exclude expenditures that are outside the VAT base
drop if item>=2201 & item<=2233 //drop own consumption/self-production
drop if item==4507 | item==4508 | item==4513 //drop zakat and charities (4507); gifts in cash (4508) and in-kind gifts (4513)
drop if item>=5201 & item<=5206 | item>=5101 & item <=5140 | item==5302 | item== 5308 | item==5331 | item==5332 | item==5310 | item==5317 | item==5333 // DROP DURABLES
drop if item==29002 //HC: Based on Arden's feedback. Drop estimated rental value for all households (mostly imputed rent since over 80% of hhs are owners)

*B2. Netting down expenditures, differentiated by location (labels say grossing up, and we don't want to change the do-files)
gen gross_expend=mvalue/(1+duty_rate_isr+vat_isr) if region_2==3 //East Jerusalem, deflated by Israeli VAT rates
	replace gross_expend=mvalue/(1+duty_rate_pa+vat_pa) if region_2==1  //West Bank, deflated by Palestinian VAT rates
	replace gross_expend=mvalue if region==2 //Gaza, assume no duty
	
*B3. Calulate direct effects from VAT, differentiated by location
gen custom_duty_d=gross_expend*duty_rate_isr*12 if region_2==3 //EJ
	replace custom_duty_d=gross_expend*duty_rate_pa*12 if region_2==1 //WB
	replace custom_duty_d=0 if custom_duty_d==. //Gaza

*B4. Calculate indirect effects from VAT (for exempt and informal goods=not eligible for VAT input credit)
*replace indirectfix=-indirectfix //REPLACE ONCE INDIRECT EFFECTS ARE CALCULATED

gen custom_duty_ind=0
	*replace vat_ind=mvalue*vat_isr*12 if region==3 //EJ: Indirect effects not available (we don't have IO matrix from Israel)
	*replace vat_ind=(mvalue/(1+indirectfix))*indirectfix*12 if region_2==1 & exempt_pa==1 //WB (Indirect effects calculated based on West Bank IO) */
	

*B5. Aggregate direct and indirect effects
gen TOT_custom_duty=custom_duty_d+custom_duty_ind	

*Downscale Total VAT to match VAT effective rate in the macro accounts (Total VAT collected from PA/Total Consumption in PA)=6.6%
	gen TOT_custom_duty_adj=$duty_scale*TOT_custom_duty
	gen custom_duty_d_adj=$duty_scale*custom_duty_d
	gen custom_duty_ind_adj=$duty_scale*custom_duty_ind

	
*B6. Aggregate results at the HH level
collapse (first) region region_2 decile hhweight popw hhsize gall_n_hh (sum) TOT_custom_duty custom_duty_d custom_duty_ind TOT_custom_duty_adj custom_duty_d_adj custom_duty_ind_adj, by(hhid)

label var gall_n_hh "HH nominal consumption annual"
label var custom_duty_d "Custom duties, direct effects, annual, HH"
label var custom_duty_ind "Custom duties indirect effects (WB), annual, HH"
label var TOT_custom_duty "Total custom duties (direct and indirect eff), annual, HH"

label var custom_duty_d_adj "Custom duties, direct effects, annual, HH (downscaled)"
label var custom_duty_ind_adj "Custom duties, indirect effects (WB), annual, HH (downscaled)"
label var TOT_custom_duty_adj "Total custom duties, annual, HH (downscaled)"

save "${temppath}PSE_Custom Duties results_HH.dta", replace

/*------------------------------------/
          C. PRELIMINARY ANALYSIS
---------------------------------------*/
use "${temppath}PSE_Custom Duties results_HH.dta", clear
collapse (sum) TOT_custom_duty custom_duty_d custom_duty_ind gall_n_hh [fw=int(hhweight)], by(region_2 decile)
export excel using "$results\PSE_Custom duty results.xls", firstrow(var) sheet(Sheet1, modify) 

use "${temppath}PSE_Custom Duties results_HH.dta", clear
collapse (sum) TOT_custom_duty_adj custom_duty_d_adj custom_duty_ind_adj gall_n_hh [fw=int(hhweight)], by(region_2 decile)
export excel using "$results\PSE_Custom duty results.xls", firstrow(var) sheet(Sheet2, modify) 

use "${temppath}PSE_Custom Duties results_HH.dta", clear
collapse (sum) TOT_custom_duty_adj custom_duty_d_adj custom_duty_ind_adj gall_n_hh [fw=int(hhweight)], by(region decile)
export excel using "$results\PSE_Custom duty results.xls", firstrow(var) sheet(Sheet3, modify) 

