*********************************************
*****PALESTINE: Fiscal Incidence Analysis*********
*****World Bank, Poverty and Equity GP*************
***********TTL: Arden Finn and Alia Jane************
*********Consultant: Haydeeliz Carrasco*************
****************************************************
*Date:  April 20th 2022
*Modified: Nov. 17th, 2022

/*DOFILE: CALCULATION OF FUEL SUBSIDIES */

/* 
Notes: calculate of subsidies comes from the background note. 
Values are in per liter

Augmented the IO matrix to disaggregate between petrol and diesel, using the consumption shares from the household survey. 

*/

/*------------------------------------/
         SET SIMULATION PARAMETERS
---------------------------------------*/

global gasoline_sub=0.0686 //NIS per liter (difference between retail price and GDoP price)
global diesel_sub=0.1962 //NIS per liter (difference between retail price and GDoP price)

*Check consumption shares of petroleum products for IO augmentation
use "${datapath}\PSE\PSE_Master Consumption.dta", clear
sort item
collapse (sum) mvalue, by (item)
*keep if item==3405| item==3406 | item==3407 | item==3408 //HC-check consumption shares of petroleum products
*bro


************************************
***A. CALCULATE INDIRECT EFFECTS****
************************************
*Note: Indirect Effects calculated for West Bank only

import excel "${io}Petroleum Augmented IO_WB.xlsx", sheet("PET_STATA IO") cellrange(A1:U21) firstrow clear 
rename sector sec

gen fixed = 0
		local fixprice "3 4 6"  //Based on discussion with Maya: IO sectors that with imported share higher than 50% (e.g. tradable price likely not affected by indirect effects)
		
		foreach sec in `fixprice' {
			replace fixed = 1 in `sec'  
		}

		gen dp = 0 // Shock= If subsidies were removed in what % would prices increase? (use consumer prices+ subsidy)
			replace dp=(((6.2300+$gasoline_sub)/6.2300)-1) if sec==3 //gasoline
			replace dp=(((5.6730+$diesel_sub)/5.6730)-1) if sec==4 //diesel
			
		costpush sector*, fixed(fixed) price(dp) genptot(totalfix) genpind(indirectfix) fix
		list totalfix indirectfix

	
		keep sec indirectfix totalfix
		rename sec sector
		sort sector	
		
save "${temppath}PSE_Fuel Subsidies_indeff.dta", replace

sum indirectfix //average indirect effect=0.2% 

*Prepare Excel with COICOP -IO Mapping
import excel "${io}Petroleum Augmented IO_WB.xlsx", sheet("IO COICOP_STATA") cellrange(A1:B924) firstrow clear 
destring item, replace
drop if item==.
save "${temp}PET_coicop.dta", replace

/*------------------------------------/
       B. DIRECT EFFECTS
---------------------------------------*/

*Open Poverty Dataset
use "${datapath}/PSE/PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta", clear
ren hhid id00
merge 1:m id00 using "${datapath}/PSE/PSE_Master Consumption.dta"
drop if _m!=3 //only keep HH's that are in the poverty dataset
drop _m
ren id00 hhid
*codebook hhid //ok- 3739 hh's

*Merge with dataset that has hh weights
merge m:1 hhid using "${temppath}hhweight_v2.dta"
drop if _m!=3 //Drop observations without household weights
drop _m

*Merge with IO-COICOP Mapping
sort item
merge m:1 item using "${temp}PET_coicop.dta" //31 not matched
drop _m

*Merge with Indirect Effects Database
merge m:1 sector using "${temppath}PSE_Fuel Subsidies_indeff.dta"
drop if _m==2 //2 obs deleted
drop _m


*Location variables 
*ta id01
*ta region, nol

gen region_2=region 
	replace region_2=3 if id01==40|id01==41

label define region 1 "West Bank" 2 "Gaza" 3 "East Jerusalem"
label val region_2 region

**Option 1: Deciles of real per capita consumption differentiated by region
quantiles gall [w=popw] if region ==1, nq(10) gencatvar(dec1)
quantiles gall [w=popw] if region ==2, nq(10) gencatvar(dec2)
gen decile=dec1 if region==1 
replace decile=dec2 if region==2

**Option 2: Deciles at the national level
quantiles gall [w=popw], nq(10) gencatvar(dec_nac)

*Total nominal consumption
gen gall_n_hh=gall_n*hhsize


/*-------------------------------------------------/
     C. CALCULATE ALL EFFECTS FROM FUEL SUBSIDIES
---------------------------------------------------*/

drop if item>=2201 & item<=2233 //drop own consumption/self-production
drop if item==4507 | item==4508 | item==4513 //drop zakat and charities (4507); gifts in cash (4508) and in-kind gifts (4513)
drop if item>=5201 & item<=5206 | item>=5101 & item <=5140 | item==5302 | item== 5308 | item==5331 | item==5332 | item==5310 | item==5317 | item==5333 // DROP DURABLES
drop if item==29002 //HC: Based on Arden's feedback. Drop estimated rental value for all households (mostly imputed rent since over 80% of hhs are owners)

*B1: DIRECT EFFECTS
*Calculate quantities
/*Gasoline, coicop=	3405, final consumer price = 6.2300 NIS/L
Diesel, coicop= 3406, final consumer price= 5.6730 /L */

//Calculate total quantity consumed by dividing total expenditure by the price per liter 

gen q_gasoline=mvalue/6.2300 
gen q_diesel=mvalue/5.6730 

*Calculate subsidy per unit 
gen fuel_sub_d=0
	replace fuel_sub_d=q_gasoline*$gasoline_sub*12 if item==3405 
	replace fuel_sub_d=q_diesel*$diesel_sub*12 if item==3406
	*replace fuel_sub_d=0 if region_2!=1
	
*B2: INDIRECT EFFECTS //MERGE
gen fuel_sub_ind=0
	replace fuel_sub_ind= (mvalue/(1+indirectfix))*indirectfix*12 if region_2==1 //Indirect effects calculated for West Bank only - but they shoudl include Gaza also. This is something we could improve in the future. 

assert !mi(fuel_sub_d) & !mi(fuel_sub_ind)
*B3: TOTAL EFFECTS
gen TOT_fuel_sub=fuel_sub_d+fuel_sub_ind

qui sum TOT_fuel_sub [w=hhweight]
disp r(sum)/1e6
	
save "${temppath}PSE_Fuel Subsidies_detail.dta", replace

/*------------------------------------/
      C.  SAVE DATASET
---------------------------------------*/
collapse (first) region region_2 decile hhweight popw hhsize gall_n_hh (sum) TOT_fuel_sub fuel_sub_d fuel_sub_ind, by(hhid)
save "${temppath}PSE_Fuel Subsidies_HH.dta", replace

/*------------------------------------/
      D.  PRELIMINARY ANALYSIS
---------------------------------------*/

use "${temppath}PSE_Fuel Subsidies_HH.dta", clear
collapse (sum) TOT_fuel_sub fuel_sub_d fuel_sub_ind gall_n_hh [fw=int(hhweight)], by(region_2 decile)
export excel using "$results\PSE_Fuel Subsidies results.xls", firstrow(var) sheet(Sheet1, modify) 

use "${temppath}PSE_Fuel Subsidies_HH.dta", clear
collapse (sum) TOT_fuel_sub fuel_sub_d fuel_sub_ind gall_n_hh [fw=int(hhweight)], by(region decile)
export excel using "$results\PSE_Fuel Subsidies results.xls", firstrow(var) sheet(Sheet2, modify)

*Check VAT results by COICOP
use  "${temppath}PSE_Fuel Subsidies_detail.dta", clear
collapse (sum)  fuel_sub_d fuel_sub_ind [fw=int(hhweight)], by(item)
export excel using  "$results\PSE_Fuel Subsidies results.xls", firstrow(var) sheet(Sheet3, modify) 
