*********************************************
*****PALESTINE: Fiscal Incidence Analysis*********
*****World Bank, Poverty and Equity GP*************
***************TTL: Arden Finn********************
*********Consultant: Haydeeliz Carrasco*************
****************************************************
*Modified: July 5th 2023

/*DOFILE: CALCULATION OF FUEL EXCISES */

/* 
We didn't have information about excise rates in Palestine, so we use the Israeli rates - but these shouldn't be very different. 
For the ones that we had information for both Israel and Palestine, the rates were very similar
*/

/*------------------------------------/
         SET SIMULATION PARAMETERS
---------------------------------------*/

*Note: Currently, we use Israeli excise rates and prices for BOTH West Bank and EJ, since the PA and ISR rates are similar
*Note: Excises rates for fuel products are about 50% of final consumer price in 2017
global gasoline_exc=2.89 //NIS per liter 
global diesel_exc=3.016 //NIS per liter
global kerosene_exc=2.89 //NIS per liter

************************************
***A. CALCULATE INDIRECT EFFECTS****
************************************
*Note: Indirect Effects calculated for West Bank only

import excel "${io}Petroleum Augmented IO_WB.xlsx", sheet("PET_STATA IO") cellrange(A1:U21) firstrow clear 
rename sector sec

gen fixed = 0
		local fixprice "3 4 6"  
		
		foreach sec in `fixprice' {
			replace fixed = 1 in `sec'  
		}

		gen dp = 0 // 
			replace dp=-$gasoline_exc/(6.91+$gasoline_exc) if sec==3 //IO=gasoline
			replace dp=-$diesel_exc/(6.06+$diesel_exc) if sec==4 //IO=diesel
			replace dp=-$kerosene_exc/(6.06+$kerosene_exc) if sec==6 //IO=Other oils 
			
		costpush sector*, fixed(fixed) price(dp) genptot(totalfix) genpind(indirectfix) fix
		list totalfix indirectfix

		keep sec indirectfix totalfix
		rename sec sector
		sort sector

		
save "${temppath}PSE_Fuel Excises_indeff.dta", replace

sum indirectfix //average indirect effect=6.3% if we exclude excise in denominator. Average indirect effect is 4.4% if we include excise in denominator


/*------------------------------------/
       B. DIRECT EFFECTS
---------------------------------------*/

*Open Poverty Dataset
use "${datapath}PSE/PSE_2016_PECS_v01_M_v04_A_MNAPOV_3.dta", clear
ren hhid id00
merge 1:m id00 using "${datapath}PSE/PSE_Master Consumption.dta"
drop if _m!=3 //only keep HH's that are in the poverty dataset
drop _m
ren id00 hhid
*codebook hhid //ok- 3739 hh's

*Merge with dataset that has hh weights
merge m:1 hhid using "${temppath}hhweight_v2.dta"
drop if _m!=3 //Drop observations without household weights
drop _m

*Merge with IO-COICOP Mapping
sort item
merge m:1 item using "${temp}PET_coicop.dta" 
drop _m

*Merge with Indirect Effects Database
merge m:1 sector using "${temppath}PSE_Fuel Excises_indeff.dta"
drop if _m==2 //2 obs deleted
drop _m


*Location variables 
*ta id01
*ta region, nol

gen region_2=region 
	replace region_2=3 if id01==40|id01==41

label define region 1 "West Bank" 2 "Gaza" 3 "East Jerusalem"
label val region_2 region

**Option 1: Deciles of real per capita consumption differentiated by region
quantiles gall [w=popw] if region ==1, nq(10) gencatvar(dec1)
quantiles gall [w=popw] if region ==2, nq(10) gencatvar(dec2)
gen decile=dec1 if region==1 
replace decile=dec2 if region==2

**Option 2: Deciles at the national level
quantiles gall [w=popw], nq(10) gencatvar(dec_nac)

*Total nominal consumption
gen gall_n_hh=gall_n*hhsize


/*-------------------------------------------------/
     C. CALCULATE ALL EFFECTS FROM FUEL EXCISES
---------------------------------------------------*/

drop if item>=2201 & item<=2233 //drop own consumption/self-production
drop if item==4507 | item==4508 | item==4513 //drop zakat and charities (4507); gifts in cash (4508) and in-kind gifts (4513)
drop if item>=5201 & item<=5206 | item>=5101 & item <=5140 | item==5302 | item== 5308 | item==5331 | item==5332 | item==5310 | item==5317 | item==5333 // DROP DURABLES
drop if item==29002 //HC: Based on Arden's feedback. Drop estimated rental value for all households (mostly imputed rent since over 80% of hhs are owners)

*B1: DIRECT EFFECTS
*Calculate quantities
*Note: Currently using Israeli prices. [Check if we should differentiate WB vs EJ and ensure consistency with fuel subsidies dofile prices]
gen q_gasoline=mvalue/6.91 if region_2==3
	replace q_gasoline=mvalue/6.22 if region_2==1
gen q_diesel=mvalue/6.06  if region_2==3 //Note: diesel price in Fuel Subsidies model is NIS 5.6730
	replace q_diesel=mvalue/5.44 if region_2==1
gen q_kerosene=mvalue/6.06 if region_2==3
	replace q_kerosene=mvalue/5.44 if region_2==1


*Calculate fuel excises per unit 
gen fuel_exc_d=0
	replace fuel_exc_d=q_gasoline*$gasoline_exc*12 if item==3405 
	replace fuel_exc_d=q_diesel*$diesel_exc*12 if item==3406
	replace fuel_exc_d=q_kerosene*$kerosene_exc*12 if item==2907
	replace fuel_exc_d=0 if region_2==2 //Assume zero direct effects for Gaza (no taxation)
	
*B2: INDIRECT EFFECTS 
replace indirectfix=-indirectfix
gen fuel_exc_ind=0
	replace fuel_exc_ind= (mvalue/(1+indirectfix))*indirectfix*12 if region_2==1 //Indirect effects at West Bank

*B3: TOTAL EFFECTS
gen TOT_fuel_exc=fuel_exc_d+fuel_exc_ind

qui sum TOT_fuel_exc [w=hhweight]
disp r(sum)/1e6
	
save "${temppath}PSE_Fuel Excises_detail.dta", replace

/*------------------------------------/
      C.  SAVE DATASET
---------------------------------------*/
collapse (first) region region_2 decile hhweight popw hhsize gall_n_hh (sum) TOT_fuel_exc fuel_exc_d fuel_exc_ind, by(hhid)
save "${temppath}PSE_Fuel Excises_HH.dta", replace

/*------------------------------------/
      D.  PRELIMINARY ANALYSIS
---------------------------------------*/

use "${temppath}PSE_Fuel Excises_HH.dta", clear
collapse (sum) TOT_fuel_exc fuel_exc_d fuel_exc_ind gall_n_hh [fw=int(hhweight)], by(region_2 decile)
export excel using "$results\PSE_Fuel Excises results.xls", firstrow(var) sheet(Sheet1, modify)

use "${temppath}PSE_Fuel Excises_HH.dta", clear
collapse (sum) TOT_fuel_exc fuel_exc_d fuel_exc_ind gall_n_hh [fw=int(hhweight)], by(region decile)
export excel using "$results\PSE_Fuel Excises results.xls", firstrow(var) sheet(Sheet2, modify)

*Check results by COICOP
use  "${temppath}PSE_Fuel Excises_detail.dta", clear
collapse (sum)  fuel_exc_d fuel_exc_ind [fw=int(hhweight)], by(decile item)
export excel using  "$results\PSE_Fuel Excises results.xls", firstrow(var) sheet(Sheet3, modify) 
